Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2572)

Unified Diff: runtime/bin/input_stream.dart

Issue 10945004: Make it possible to read a specific number of characters from a string input stream (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/bin/file_impl.dart ('k') | runtime/bin/string_stream.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/bin/input_stream.dart
diff --git a/runtime/bin/input_stream.dart b/runtime/bin/input_stream.dart
index 38e8f1d81e3d0fa473d07af41863ca2682790c8e..e2e57fcec92270afdff90d2cd60ccad0851247ac 100644
--- a/runtime/bin/input_stream.dart
+++ b/runtime/bin/input_stream.dart
@@ -122,10 +122,11 @@ interface StringInputStream default _StringInputStream {
StringInputStream(InputStream input, [Encoding encoding]);
/**
* Reads as many characters as is available from the stream. If no data is
* available null will be returned.
*/
- String read();
+ String read([int len]);
/**
* Reads the next line from the stream. The line ending characters
« no previous file with comments | « runtime/bin/file_impl.dart ('k') | runtime/bin/string_stream.dart » ('j') | no next file with comments »
@@ -122,10 +122,11 @@ interface StringInputStream default _StringInputStream {
StringInputStream(InputStream input, [Encoding encoding]);
/**
- * Reads as many characters as is available from the stream. If no data is
- * available null will be returned.
+ * Reads up to [len] characters from the stream. if [len] is not
+ * specified reads as many characters as is available from the
+ * stream. If no data is available null will be returned.
*/

Powered by Google App Engine
This is Rietveld 408576698